@@ -1,16 +1,13 @@
 package ojo::ServeDir;
 
-use 5.020;
 use strict;
 use warnings FATAL => 'all';
+use ojo::ServeDir::App;
 
-use ojo;
-
-our $VERSION = '0.02';
+our $VERSION = '0.1';
 
 sub import {
-    push @{app->static->paths}, app->home->rel_file('.');
-    app->start('daemon');
+    ojo::ServeDir::App->new->start('daemon');
 }
 
 1;
@@ -23,12 +20,20 @@ ojo::ServeDir - Helper module to serve local files
 
 =head1 VERSION
 
-Version 0.01
+Version 0.1
 
 =head1 SYNOPSIS
 
+Module import interface:
+
     $ perl -Mojo::ServeDir
 
+Command interface:
+
+    $ serve_dir DIRECTORY_NAME OPTIONS
+
+The directory name is optional (default is the current working directory), options go directly to Mojo's C<daemon> command.
+
 =head1 CONTRIBUTORS
 
 =over 4
